@@ -1,5 +1,5 @@
 package Starch;
-$Starch::VERSION = '0.08';
+$Starch::VERSION = '0.09';
 use Starch::Factory;
 use Moo::Object qw();
 
@@ -140,9 +140,9 @@ making changes to the data, call save:
 
 This stores the state data in the store.
 
-Each state gets assigned a state ID automatically which can be
-used to retrieve the state data at a later time.  The state ID
-is a randomly generated SHA-1 hex digest.
+Each state gets assigned a state ID automatically, unless you specify a custom
+one when creating the state, which can be used to retrieve the state data at a
+later time.  The state ID is a randomly generated SHA-1 hex digest.
 
     my $id = $state->id();
 
@@ -161,8 +161,8 @@ it's still good to know what is happening behind the scenes.
 
 =head1 EXPIRATION
 
-Expiration can be specified globally, when instantiating the L<Starch::Manager>
-object, per-state, and per-store.  The expires value has various properties
+Expiration can be specified globally when instantiating the L<Starch::Manager>
+object, as well as per-state and per-store.  The expires value has various properties
 and behaviors that are important to understand:
 
 =over
@@ -174,6 +174,12 @@ the state will expire.
 
 =item *
 
+Setting C<expires> to C<0> generally disables expiration, but behavior
+can be store-specific.  For example, often times caching stores assume no
+expiration to mean the storage backend gets to pick when the expire the data.
+
+=item *
+
 The L<Starch::Manager> class accepts an C<expires> argument which is used
 as the default expires for new state objects and used as the expiration
 for cookies via L<Starch::Plugin::CookieArgs>.
@@ -187,10 +193,15 @@ L<Starch::State/set_expires> method.
 
 =item *
 
-Stores may have a C<max_expires> argument passed to them.  If the per-state
+Stores may have a C<max_expires> argument passed to them.  If the state's
 expires is larger than the store's max_expires then the state's expires will
 be replaced with the store's max_expires when writing the data to the store.
 
+This is useful for when you have a caching store in front of your persistent
+store and you'd like your sessions to expire out of the caching store, by
+setting C<max_expires> on it, well before they will expire out of the
+persistent store.
+
 =back
 
 =head1 LOGGING
@@ -299,6 +310,10 @@ L<Starch::Store::Amazon::DynamoDB>
 
 =item *
 
+L<Starch::Store::Catalyst::Plugin::Session>
+
+=item *
+
 L<Starch::Store::CHI> - This store is a meta-store which provides
 access to many other stores such as L<CHI::Driver::Redis>,
 L<CHI::Driver::BerkleyDB>, L<CHI::Driver::File>, L<CHI::Driver::FastMmap>,
@@ -315,7 +330,7 @@ L<Starch::Store::DBIx::Connector>
 =back
 
 More third-party stores can be found on
-L<meta::cpan|https://metacpan.org/search?q=Web%3A%3AStarch%3A%3AStore>.
+L<meta::cpan|https://metacpan.org/search?q=Starch%3A%3AStore>.
 
 =head1 PLUGINS
 
@@ -374,6 +389,10 @@ L<Starch::Plugin::Net::Statsd>
 
 =item *
 
+L<Starch::Plugin::SecureStateID>
+
+=item *
+
 L<Starch::Plugin::Sereal>
 
 =item *
@@ -383,7 +402,7 @@ L<Starch::Plugin::TimeoutStore>
 =back
 
 More third-party plugins can be found on
-L<meta::cpan|https://metacpan.org/search?q=Web%3A%3AStarch%3A%3APlugin>.
+L<meta::cpan|https://metacpan.org/search?q=Starch%3A%3APlugin>.
 
 =head1 INTEGRATIONS
 
@@ -467,7 +486,7 @@ Jonathan Scott Duff <duffE<64>pobox.com>
 
 =item *
 
-Ismail Kerim <ismail.kerim<64>assurant.com>
+Ismail Kerim <ismail.kerimE<64>assurant.com>
 
 =back
 
