@@ -1,5 +1,5 @@
 package Starch::Manager;
-$Starch::Manager::VERSION = '0.08';
+$Starch::Manager::VERSION = '0.09';
 =head1 NAME
 
 Starch::Manager - Entry point for accessing Starch state objects.
@@ -88,21 +88,6 @@ sub _build_store {
     );
 }
 
-=head2 factory
-
-The underlying L<Starch::Factory> object which manages all the plugins
-and state/store object construction.
-
-This argument is automatically set when calling C<new> on L<Starch>.
-
-=cut
-
-has factory => (
-    is       => 'ro',
-    isa      => InstanceOf[ 'Starch::Factory' ],
-    required => 1,
-);
-
 =head1 OPTIONAL ARGUMENTS
 
 =head2 expires
@@ -225,6 +210,21 @@ has dirty_state_key => (
 
 =head1 ATTRIBUTES
 
+=head2 factory
+
+The L<Starch::Factory> object which applies plugins and handles the
+construction of the manager, state, and store objects.
+
+=cut
+
+# This argument is always set by Starch->new().  So, to the end-user,
+# this is an attribute not a required argument.
+has factory => (
+    is       => 'ro',
+    isa      => InstanceOf[ 'Starch::Factory' ],
+    required => 1,
+);
+
 =head2 state_id_type
 
 The L<Type::Tiny> object to validate the state ID when L</state>
